/**
 * @module package/quiqqer/trustedshops/bin/backend/controls/ChannelSelect
 */
define('package/quiqqer/trustedshops/bin/backend/controls/ChannelSelect', [

    'qui/QUI',
    'qui/controls/Control',
    'Ajax'

], function (QUI, QUIControl, QUIAjax) {
    "use strict";

    return new Class({

        Extends: QUIControl,
        Type   : 'package/quiqqer/trustedshops/bin/backend/controls/ChannelSelect',

        Binds: [
            '$onImport',
            'refresh'
        ],

        initialize: function (options) {
            this.parent(options);

            this.$Select = null;
            this.$Project = null;

            this.addEvents({
                onImport: this.$onImport
            });
        },

        refresh: function () {
            if (!this.$Project) {
                return;
            }

            const currentValue = this.$Select.value;

            this.$Select.set('disabled', true);
            this.$Select.set('html', '');

            QUIAjax.get('package_quiqqer_trustedshops_ajax_getChannels', (list) => {
                for (let i = 0, len = list.length; i < len; i++) {
                    new Element('option', {
                        value: list[i].id,
                        html : list[i].name + ' - ' + list[i].address
                    }).inject(this.$Select);
                }

                this.$Select.value = currentValue;
                this.$Select.set('disabled', false);

                if (list.length === 1) {
                    this.$Select.value = list[0].id;
                    this.$Select.fireEvent('change');
                }
            }, {
                'package': 'quiqqer/trustedshops',
                project  : this.$Project.encode()
            });

        },

        $onImport: function () {
            if (this.$Elm.nodeName !== 'SELECT') {
                this.$Elm.type = 'hidden';
                this.$Select = new Element('select', {
                    disabled: true
                }).inject(this.$Elm, 'after');

                if (this.$Elm.hasClass('field-container-field')) {
                    this.$Select.addClass('field-container-field');
                }
            } else {
                this.$Select = this.$Elm;
            }

            this.$Select.addEvent('change', () => {
                if (this.$Elm.nodeName === 'INPUT') {
                    this.$Elm.value = this.$Select.value;
                }
            });

            // check client id
            // check api key
            const CientId = this.$Elm.getParent('table').getChildren('[name="trustedshops.api.clientId"]');
            const ApiKey = this.$Elm.getParent('table').getChildren('[name="trustedshops.api.key"]');

            if (CientId) {
                CientId.addEvent('blur', this.refresh);
            }

            if (ApiKey) {
                ApiKey.addEvent('blur', this.refresh);
            }

            if (this.$Project) {
                this.refresh();
            }
        },

        setProject: function (Project) {
            this.$Project = Project;
            this.refresh();
        }
    });
});